From 2b5c60f130bf5d6e0ad4521d327b81947cd2eab7 Mon Sep 17 00:00:00 2001
From: ulrich
Date: Mon, 05 Apr 2021 13:42:39 +0000
Subject: [PATCH] Alle Faelle (Liste, Neu, Lesen, Aendern, Loeschen) fuer Ablageort fertig

---
 src/de/uhilger/mediaz/store/FileStorage.java |   41 +++++++++++++++++++++++++++++++----------
 1 files changed, 31 insertions(+), 10 deletions(-)

diff --git a/src/de/uhilger/mediaz/store/FileStorage.java b/src/de/uhilger/mediaz/store/FileStorage.java
index 3819699..90a99a1 100644
--- a/src/de/uhilger/mediaz/store/FileStorage.java
+++ b/src/de/uhilger/mediaz/store/FileStorage.java
@@ -1,7 +1,19 @@
 /*
- * To change this license header, choose License Headers in Project Properties.
- * To change this template file, choose Tools | Templates
- * and open the template in the editor.
+  Mediazentrale - Personal Media Center
+  Copyright (C) 2021  Ulrich Hilger
+
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU Affero General Public License as
+  published by the Free Software Foundation, either version 3 of the
+  License, or (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Affero General Public License for more details.
+
+  You should have received a copy of the GNU Affero General Public License
+  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 package de.uhilger.mediaz.store;
 
@@ -25,7 +37,7 @@
 import java.util.logging.Level;
 
 /**
  * Ablage fuer Dateien
  * 
  * [Basispfad]/[Typ]/[Name]
  * 
@@ -66,20 +78,20 @@
    * Der Name der Ablage muss eindeutig sein
    * 
    * 
-   * @param o 
+   * @param entity 
    */
-  public File writeToFile(Entity o) throws IOException {
-    String className = o.getClass().getSimpleName();
+  public File writeToFile(Entity entity) throws IOException {
+    String className = entity.getClass().getSimpleName();
     logger.finer(className); 
     File dir = new File(fileBase, className);
     dir.mkdirs();
-    File file = new File(dir, o.getName());
+    File file = new File(dir, entity.getName());
     if(file.exists()) {
       file.delete();
     }
     FileWriter fw = new FileWriter(file);
     Gson gson = new Gson();
-    fw.write(gson.toJson(o));
+    fw.write(gson.toJson(entity));
     fw.flush();
     fw.close();
     return file;
@@ -105,7 +117,6 @@
   
   private String typeNameFromPath(File file) {
     String[] parts = file.getPath().split(App.getRs(Server.RB_SLASH));
-    logger.info(parts[parts.length-2]);
     return parts[parts.length-2];
   }
 
@@ -162,6 +173,16 @@
     return new File(dir, name);    
   }
 
+  @Override
+  public boolean delete(String typ, String name) {
+    File file = getFile(typ, name);
+    if(file.exists()) {
+      return file.delete();
+    } else {
+      return false;
+    }
+  }
+
   
   
 }
@@ -25,7 +37,7 @@
 
 /**
- * Ablage fuer Dateien
+ * Ablage fuer Dateien der Mediazentrale
  * 
  * [Basispfad]/[Typ]/[Name]

--
Gitblit v1.9.3